==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ug.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "ئاممىۋى ئۇلىنىش",
    "Photos" : "Photos",
    "On This Day" : "بۇ كۈندە",
    "Your memories under your control" : "ئەسلىمىلىرىڭىز سىزنىڭ كونتروللۇقىڭىزدا",
    "All media" : "بارلىق تاراتقۇلار",
    "Videos" : "سىنلار",
    "Albums" : "Album",
    "Collaborative albums" : "ھەمكارلىق پىلاستىنكىسى",
    "People" : "كىشىلەر",
    "Folders" : "ھۆججەت قىسقۇچ",
    "Favorites" : "يىغقۇچ",
    "On this day" : "بۇ كۈنى",
    "Shared with you" : "Shared with you",
    "Tags" : "بەلگەلەر",
    "Places" : "جايلار",
    "Map" : "خەرىتە",
    "Photos settings" : "رەسىم تەڭشىكى",
    "Mark selection as favorite" : "تاللاشقا ئامراق دەپ بەلگە قويۇڭ",
    "Add selection to favorites" : "ياقتۇرىدىغانلارغا تاللاش قوشۇڭ",
    "Remove selection from favorites" : "ياقتۇرىدىغانلاردىن تاللاشنى ئۆچۈرۈڭ",
    "This name is already in use." : "بۇ ئىسىم ئاللىقاچان ئىشلىتىلىۋاتىدۇ.",
    "\"{char}\" is not allowed inside a filename." : "ھۆججەت نامىدا \"{char}\" رۇخسەت قىلىنمايدۇ.",
    "Invalid filename." : "ئىناۋەتسىز ھۆججەت ئىسمى.",
    "Name of the album" : "پىلاستىنكىنىڭ ئىسمى",
    "Location of the album" : "ئالبۇمنىڭ ئورنى",
    "Back" : "قايتىش",
    "Add collaborators" : "ھەمكارلاشقۇچىلارنى قوشۇڭ",
    "Save" : "ساقلا",
    "Create album" : "پىلاستىنكا قۇرۇش",
    "Add to Album" : "ئالبۇمغا قوشۇڭ",
    "Add selection to album {albumName}" : "پىلاستىنكا تاللاش {albumName}",
    "Shared by" : "ھەمبەھىرلىگۈچى",
    "Create a new album." : "يېڭى پىلاستىنكا قۇر.",
    "Create new album" : "يېڭى پىلاستىنكا قۇر",
    "New album" : "يېڭى پىلاستىنكا",
    "Failed to fetch collaborators list." : "ھەمكارلاشقۇچىلار تىزىملىكىنى ئالالمىدى.",
    "Failed to update album." : "پىلاستىنكىنى يېڭىلاش مەغلۇب بولدى.",
    "Add people or groups who can edit your album" : "پىلاستىنكىڭىزنى تەھرىرلىيەلەيدىغان كىشىلەر ياكى گۇرۇپپىلارنى قوشۇڭ",
    "Search people or groups" : "كىشىلەرنى ياكى گۇرۇپپىلارنى ئىزدەڭ",
    "No recommendations. Start typing." : "تەۋسىيە يوق. يېزىشنى باشلاڭ.",
    "Copy the public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Public link copied!" : "ئاممىۋى ئۇلىنىش كۆچۈرۈلدى!",
    "Copy public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Delete the public link" : "ئاممىۋى ئۇلىنىشنى ئۆچۈرۈڭ",
    "Create public link share" : "ئاممىۋى ئۇلىنىش ئورتاقلىشىش",
    "Share via public link" : "ئاممىۋى ئۇلىنىش ئارقىلىق ھەمبەھىرلەڭ",
    "This collection does not exist" : "بۇ توپلام مەۋجۇت ئەمەس",
    "An error occurred" : "خاتالىق كۆرۈلدى",
    "No picture for this day" : "بۇ كۈنگە ھېچقانداق رەسىم يوق",
    "Picture taken on this day will show up here." : "بۇ كۈنى تارتىلغان رەسىم بۇ يەردە كۆرسىتىلىدۇ.",
    "More photos from this day" : "بۇ كۈندىن باشلاپ تېخىمۇ كۆپ سۈرەتلەر",
    "Favorite" : "يىغقۇچ",
    "Favorite image, open the full size \"{name}\" image" : "ياقتۇرىدىغان رەسىم ، چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Open the full size \"{name}\" image" : "تولۇق چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Select image {imageName}" : "رەسىم {imageName} Select نى تاللاڭ",
    "Open the \"{name}\" folder" : "\"{name}\" ھۆججەت قىسقۇچىنى ئېچىڭ",
    "Go back" : "قايتىڭ",
    "Dates" : "چېسلا",
    "Jump to specific date in list" : "تىزىملىكتىكى كونكرېت چېسلاغا ئاتلاڭ",
    "Jump to {date}" : "{date} ئاتلاڭ",
    "Add to {destination}" : "{destination} قوش",
    "The destination folder is owned by {owner}" : "نىشان ھۆججەت قىسقۇچى {owner} نىڭ ئىگىدارچىلىقىدا",
    "There are no photos or videos yet!" : "ھازىرچە رەسىم ياكى سىن يوق!",
    "Enable squared photos view" : "كۋادرات رەسىم كۆرۈنۈشىنى قوزغىتىڭ",
    "Delete source directory" : "مەنبە مۇندەرىجىسىنى ئۆچۈرۈڭ",
    "Select a source folder for your media" : "مېدىياڭىزنىڭ مەنبە قىسقۇچىنى تاللاڭ",
    "All folders" : "بارلىق ھۆججەت قىسقۇچلار",
    "Add a Photos source for the timelines" : "ۋاقىت جەدۋىلىگە رەسىم مەنبەسىنى قوشۇڭ",
    "Add folder" : "قىسقۇچ قوشۇڭ",
    "Select the default upload location for your media" : "مېدىياڭىزنىڭ سۈكۈتتىكى يۈكلەش ئورنىنى تاللاڭ",
    "Home" : "ئۆي",
    "Choose default Photos upload and Albums location" : "سۈكۈتتىكى رەسىم يوللاش ۋە پىلاستىنكا ئورنىنى تاللاڭ",
    "Choose a different folder" : "باشقا ھۆججەت قىسقۇچنى تاللاڭ",
    "View" : "كۆرۈش",
    "Media folders" : "مېدىيا قىسقۇچلىرى",
    "Choose the folders from where photos and videos are shown." : "رەسىم ۋە سىن كۆرسىتىلگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Upload folder" : "ھۆججەت قىسقۇچنى يۈكلەڭ",
    "Choose the folder where photos and albums are uploaded to." : "رەسىم ۋە پىلاستىنكىلار يۈكلەنگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Unselect all" : "ھەممىنى تاللاڭ",
    "Add photos to this album" : "بۇ پىلاستىنكىغا رەسىم قوشۇڭ",
    "Manage collaborators for this album" : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى باشقۇرۇڭ",
    "Open actions menu" : "ھەرىكەت تىزىملىكى",
    "Edit album details" : "پىلاستىنكا تەپسىلاتلىرىنى تەھرىرلەڭ",
    "Download all files in album" : "ئالبۇمدىكى بارلىق ھۆججەتلەرنى چۈشۈرۈڭ",
    "Delete album" : "ئالبۇمنى ئۆچۈرۈڭ",
    "Download selected files" : "تاللانغان ھۆججەتلەرنى چۈشۈرۈڭ",
    "Remove selection from album" : "ئالبۇمدىن تاللاشنى ئۆچۈرۈڭ",
    "This album does not have any photos or videos yet!" : "بۇ پىلاستىنكىدا ھازىرچە ھېچقانداق رەسىم ياكى سىن يوق!",
    "Add photos to {albumName}" : "{albumName} to غا رەسىم قوشۇڭ",
    "Manage collaborators" : "ھەمكارلاشقۇچىلارنى باشقۇرۇش",
    "Save collaborators for this album." : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى ساقلاڭ.",
    "Cover photo for album {albumName}" : "پىلاستىنكا {albumName} for نىڭ مۇقاۋا سۈرىتى",
    "There is no album yet!" : "ھازىرچە ئالبۇم يوق!",
    "This person could not be found" : "بۇ ئادەمنى تاپالمىدى",
    "Rename person" : "ئادەمنىڭ نامىنى ئۆزگەرتىش",
    "Merge with different person" : "ئوخشىمىغان ئادەم بىلەن بىرلەشتۈرۈڭ",
    "Download selected photos" : "تاللانغان رەسىملەرنى چۈشۈرۈڭ",
    "Remove from favorites" : "Remove from favorites",
    "Remove person" : "ئادەمنى چىقىرىۋېتىڭ",
    "Name of this person" : "بۇ كىشىنىڭ ئىسمى",
    "Save." : "ساقلاش.",
    "Merge person" : "ئادەمنى بىرلەشتۈرۈش",
    "Move to different person" : "ئوخشىمىغان ئادەمگە يۆتكىڭ",
    "This might take some time depending on the size of your photo library." : "رەسىم ئامبىرىڭىزنىڭ چوڭ-كىچىكلىكىگە ئاساسەن بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
    "Recognized people will show up here" : "تونۇلغان كىشىلەر بۇ يەردە پەيدا بولىدۇ",
    "This folder does not exist" : "بۇ ھۆججەت قىسقۇچ مەۋجۇت ئەمەس",
    "No photos in here" : "بۇ يەردە رەسىم يوق",
    "Taken on {date} at {time}" : "{date} دا {time} دىن ئېلىندى",
    "This place does not have any photos or videos yet!" : "بۇ يەرنىڭ تېخى رەسىم ياكى سىن يوق!",
    "Add photos to this place" : "بۇ يەرگە رەسىم قوشۇڭ",
    "Cover photo for place {placeName}" : "ئورۇننىڭ يېپىلىش سۈرىتى {placeName}",
    "There is no place yet!" : "ھازىرچە يەر يوق!",
    "Back to tags overview" : "خەتكۈچ ئومۇمىي كۆرۈنۈشىگە قايتىڭ",
    "No photos with this tag yet" : "بۇ خەتكۈچ بىلەن رەسىم يوق",
    "No tags yet" : "خەتكۈچ يوق",
    "Photos with tags will show up here" : "بەلگە قويۇلغان رەسىملەر بۇ يەردە كۆرۈنىدۇ",
    "Popular tags" : "داڭلىق خەتكۈچلەر",
    "All tags" : "بارلىق خەتكۈچلەر",
    "Add to album" : "ئالبۇمغا قوشۇڭ",
    "Delete selection" : "تاللاشنى ئۆچۈرۈڭ",
    "No photos or videos in here" : "بۇ يەردە رەسىم ياكى سىن يوق",
    "Unassigned faces" : "ئىمزاسىز چىراي",
    "Failed to fetch collection." : "يىغىش مەغلۇب بولدى.",
    "Failed to fetch collections list." : "يىغىپ ساقلاش تىزىملىكىنى ئالالمىدى.",
    "Failed to fetch faces list." : "چىراي تىزىملىكىنى ئالالمىدى.",
    "All your media" : "بارلىق مېدىيالىرىڭىز",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "ھەمبەھىرلەنگەن ئالبۇم",
    "Shared album {title}" : "ھەمبەھىرلەنگەن پىلاستىنكا {title}",
    "Public album {title}" : "ئاممىۋى پىلاستىنكا {title}",
    "Tagged photos" : "خەتكۈچلەنگەن رەسىملەر",
    "Tagged photo {title}" : "خەتكۈچلەنگەن رەسىم {title}",
    "{title}'s face" : "{title} 'face",
    "Last week" : "ئالدىنقى ھەپتە",
    "{startDate} to {endDate}" : "{startDate} دىن {endDate}",
    "Details" : "تەپسىلاتى",
    "Could not load photos folder" : "رەسىم قىسقۇچنى يۈكلىيەلمىدى",
    "Group" : "گۇرۇپپا",
    "Remove {collaboratorLabel} from the collaborators list" : "ھەمكارلاشقۇچىلار تىزىملىكىدىن {collaboratorLabel} Label ئۆچۈرۈڭ",
    "Back to {folder}" : "{folder} قايتىش",
    "Share this folder" : "بۇ قىسقۇچنى ھەمبەھىرلەڭ",
    "Loading folders …" : "ھۆججەت قىسقۇچلارنى يۈكلەۋاتىدۇ…",
    "Add" : "قوش"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ug.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "ئاممىۋى ئۇلىنىش",
    "Photos" : "سۈرەتلەر",
    "On This Day" : "بۇ كۈندە",
    "Your memories under your control" : "ئەسلىمىلىرىڭىز سىزنىڭ كونتروللۇقىڭىزدا",
    "All media" : "بارلىق تاراتقۇلار",
    "Videos" : "سىنلار",
    "Albums" : "توپلاملار",
    "Collaborative albums" : "ھەمكارلىق پىلاستىنكىسى",
    "People" : "كىشىلەر",
    "Folders" : "ھۆججەت قىسقۇچ",
    "Favorites" : "يىغقۇچ",
    "On this day" : "بۇ كۈنى",
    "Shared with you" : "سىز بىلەن ئورتاقلاشتى",
    "Tags" : "بەلگەلەر",
    "Places" : "جايلار",
    "Map" : "خەرىتە",
    "Photos settings" : "رەسىم تەڭشىكى",
    "Mark selection as favorite" : "تاللاشقا ئامراق دەپ بەلگە قويۇڭ",
    "Add selection to favorites" : "ياقتۇرىدىغانلارغا تاللاش قوشۇڭ",
    "Remove selection from favorites" : "ياقتۇرىدىغانلاردىن تاللاشنى ئۆچۈرۈڭ",
    "This name is already in use." : "بۇ ئىسىم ئاللىقاچان ئىشلىتىلىۋاتىدۇ.",
    "\"{char}\" is not allowed inside a filename." : "ھۆججەت نامىدا \"{char}\" رۇخسەت قىلىنمايدۇ.",
    "Invalid filename." : "ئىناۋەتسىز ھۆججەت ئىسمى.",
    "Name of the album" : "پىلاستىنكىنىڭ ئىسمى",
    "Location of the album" : "ئالبۇمنىڭ ئورنى",
    "Back" : "قايتىش",
    "Add collaborators" : "ھەمكارلاشقۇچىلارنى قوشۇڭ",
    "Save" : "ساقلا",
    "Create album" : "پىلاستىنكا قۇرۇش",
    "Add to Album" : "ئالبۇمغا قوشۇڭ",
    "Add selection to album {albumName}" : "پىلاستىنكا تاللاش {albumName}",
    "Shared by" : "ھەمبەھىرلىگۈچى",
    "Create a new album." : "يېڭى پىلاستىنكا قۇر.",
    "Create new album" : "يېڭى پىلاستىنكا قۇر",
    "New album" : "يېڭى پىلاستىنكا",
    "_%n item_::_%n photos and videos_" : ["%n تارماق","%n سۈرەتلەر ھەمدە سىنلار"],
    "Failed to fetch collaborators list." : "ھەمكارلاشقۇچىلار تىزىملىكىنى ئالالمىدى.",
    "Failed to update album." : "پىلاستىنكىنى يېڭىلاش مەغلۇب بولدى.",
    "Add people or groups who can edit your album" : "پىلاستىنكىڭىزنى تەھرىرلىيەلەيدىغان كىشىلەر ياكى گۇرۇپپىلارنى قوشۇڭ",
    "Search people or groups" : "كىشىلەرنى ياكى گۇرۇپپىلارنى ئىزدەڭ",
    "No recommendations. Start typing." : "تەۋسىيە يوق. يېزىشنى باشلاڭ.",
    "Copy the public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Public link copied!" : "ئاممىۋى ئۇلىنىش كۆچۈرۈلدى!",
    "Copy public link" : "ئاممىۋى ئۇلىنىشنى كۆچۈرۈڭ",
    "Delete the public link" : "ئاممىۋى ئۇلىنىشنى ئۆچۈرۈڭ",
    "Create public link share" : "ئاممىۋى ئۇلىنىش ئورتاقلىشىش",
    "Share via public link" : "ئاممىۋى ئۇلىنىش ئارقىلىق ھەمبەھىرلەڭ",
    "This collection does not exist" : "بۇ توپلام مەۋجۇت ئەمەس",
    "An error occurred" : "خاتالىق كۆرۈلدى",
    "No picture for this day" : "بۇ كۈنگە ھېچقانداق رەسىم يوق",
    "Picture taken on this day will show up here." : "بۇ كۈنى تارتىلغان رەسىم بۇ يەردە كۆرسىتىلىدۇ.",
    "More photos from this day" : "بۇ كۈندىن باشلاپ تېخىمۇ كۆپ سۈرەتلەر",
    "_%n photos_::_%n photos_" : ["%n سۈرەتلەر","%n سۈرەتلەر"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n تەقسىملەنمىگەن سۈرەتلەر","%n تەقسىملەنمىگەن سۈرەتلەر"],
    "Favorite" : "يىغقۇچ",
    "Favorite image, open the full size \"{name}\" image" : "ياقتۇرىدىغان رەسىم ، چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Open the full size \"{name}\" image" : "تولۇق چوڭلۇقتىكى \"{name}\" رەسىمنى ئېچىڭ",
    "Select image {imageName}" : "رەسىم {imageName} Select نى تاللاڭ",
    "Open the \"{name}\" folder" : "\"{name}\" ھۆججەت قىسقۇچىنى ئېچىڭ",
    "Go back" : "قايتىڭ",
    "Select a custom date range" : "ئىختىيارى چېسلا دائىرىسىنى تاللاڭ",
    "Select a date range" : "ھۆججەت دائىرىسىنى تاللاڭ",
    "Date range" : "چېسلا دائىرىسى",
    "Select filters" : "سۈزگۈچ تاللاڭ",
    "Dates" : "چېسلا",
    "Jump to specific date in list" : "تىزىملىكتىكى كونكرېت چېسلاغا ئاتلاڭ",
    "Jump to {date}" : "{date} ئاتلاڭ",
    "Add to {destination}" : "{destination} قوش",
    "The destination folder is owned by {owner}" : "نىشان ھۆججەت قىسقۇچى {owner} نىڭ ئىگىدارچىلىقىدا",
    "There are no photos or videos yet!" : "ھازىرچە رەسىم ياكى سىن يوق!",
    "_{years} year ago_::_{years} years ago_" : ["{years} يىل ئىلگىرى","{years} يىل ئىلگىرى"],
    "Squared photos view" : "كۋادرات رەسىم كۆرۈنۈشى",
    "Delete source directory" : "مەنبە مۇندەرىجىسىنى ئۆچۈرۈڭ",
    "Pick folder" : "قىسقۇچ تاللاڭ",
    "Select a source folder for your media" : "مېدىياڭىزنىڭ مەنبە قىسقۇچىنى تاللاڭ",
    "Media folders" : "مېدىيا قىسقۇچلىرى",
    "Choose the folders from where photos and videos are shown." : "رەسىم ۋە سىن كۆرسىتىلگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "All folders" : "بارلىق ھۆججەت قىسقۇچلار",
    "Add a Photos source for the timelines" : "ۋاقىت جەدۋىلىگە رەسىم مەنبەسىنى قوشۇڭ",
    "Add folder" : "قىسقۇچ قوشۇڭ",
    "Home" : "ئۆي",
    "Select the default upload location for your media" : "مېدىياڭىزنىڭ سۈكۈتتىكى يۈكلەش ئورنىنى تاللاڭ",
    "Upload folder" : "ھۆججەت قىسقۇچنى يۈكلەڭ",
    "General" : "ئۇمۇمىي",
    "_%n photo_::_%n photos_" : ["%n سۈرەتلەر","%n سۈرەتلەر"],
    "Unselect all" : "ھەممىنى تاللاڭ",
    "Add photos to this album" : "بۇ پىلاستىنكىغا رەسىم قوشۇڭ",
    "Manage collaborators for this album" : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى باشقۇرۇڭ",
    "Open actions menu" : "ھەرىكەت تىزىملىكى",
    "Edit album details" : "پىلاستىنكا تەپسىلاتلىرىنى تەھرىرلەڭ",
    "Download all files in album" : "ئالبۇمدىكى بارلىق ھۆججەتلەرنى چۈشۈرۈڭ",
    "Delete album" : "ئالبۇمنى ئۆچۈرۈڭ",
    "Download selected files" : "تاللانغان ھۆججەتلەرنى چۈشۈرۈڭ",
    "Remove selection from album" : "ئالبۇمدىن تاللاشنى ئۆچۈرۈڭ",
    "This album does not have any photos or videos yet!" : "بۇ پىلاستىنكىدا ھازىرچە ھېچقانداق رەسىم ياكى سىن يوق!",
    "Add photos to {albumName}" : "{albumName} غا رەسىم قوشۇڭ",
    "Manage collaborators" : "ھەمكارلاشقۇچىلارنى باشقۇرۇش",
    "Save collaborators for this album." : "بۇ ئالبۇم ئۈچۈن ھەمكارلاشقۇچىلارنى ساقلاڭ.",
    "Cover photo for album {albumName}" : "پىلاستىنكا {albumName} نىڭ مۇقاۋا سۈرىتى",
    "There is no album yet!" : "ھازىرچە ئالبۇم يوق!",
    "This person could not be found" : "بۇ ئادەمنى تاپالمىدى",
    "Rename person" : "ئادەمنىڭ نامىنى ئۆزگەرتىش",
    "Merge with different person" : "ئوخشىمىغان ئادەم بىلەن بىرلەشتۈرۈڭ",
    "Download selected photos" : "تاللانغان رەسىملەرنى چۈشۈرۈڭ",
    "Remove from favorites" : "ياقتۇردىغاندىن چىقىرۋەت",
    "Remove person" : "ئادەمنى چىقىرىۋېتىڭ",
    "Name of this person" : "بۇ كىشىنىڭ ئىسمى",
    "Save." : "ساقلاش.",
    "Merge person" : "ئادەمنى بىرلەشتۈرۈش",
    "Move to different person" : "ئوخشىمىغان ئادەمگە يۆتكىڭ",
    "_Move photo to a different person_::_Move photos to a different person_" : ["رەسىملەرنى ئوخشىمىغان ئادەمگە يۆتكىڭ","رەسىملەرنى ئوخشىمىغان ئادەمگە يۆتكىڭ"],
    "_Remove photo from person_::_Remove photos from person_" : ["رەسىملەرنى بىرەيلەندىن چىقىرۋەت","رەسىملەرنى بىرەيلەندىن چىقىرۋەت"],
    "This might take some time depending on the size of your photo library." : "رەسىم ئامبىرىڭىزنىڭ چوڭ-كىچىكلىكىگە ئاساسەن بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
    "Recognized people will show up here" : "تونۇلغان كىشىلەر بۇ يەردە پەيدا بولىدۇ",
    "This folder does not exist" : "بۇ ھۆججەت قىسقۇچ مەۋجۇت ئەمەس",
    "Loading folders…" : "قىسقۇچلارنى يۈكلەۋاتىدۇ...",
    "No photos in here" : "بۇ يەردە رەسىم يوق",
    "Taken on {date} at {time}" : "{date} دا {time} دىن ئېلىندى",
    "This place does not have any photos or videos yet!" : "بۇ يەرنىڭ تېخى رەسىم ياكى سىن يوق!",
    "Add photos to this place" : "بۇ يەرگە رەسىم قوشۇڭ",
    "Cover photo for place {placeName}" : "ئورۇننىڭ يېپىلىش سۈرىتى {placeName}",
    "There is no place yet!" : "ھازىرچە يەر يوق!",
    "Cover photo for shared album {albumName}" : "ھەمبەھىرلەنگەن {albumName} توپلامنىڭ مۇقاۋا رەسىمى",
    "Back to tags overview" : "خەتكۈچ ئومۇمىي كۆرۈنۈشىگە قايتىڭ",
    "No photos with this tag yet" : "بۇ خەتكۈچ بىلەن رەسىم يوق",
    "No tags yet" : "خەتكۈچ يوق",
    "Photos with tags will show up here" : "بەلگە قويۇلغان رەسىملەر بۇ يەردە كۆرۈنىدۇ",
    "Popular tags" : "داڭلىق خەتكۈچلەر",
    "All tags" : "بارلىق خەتكۈچلەر",
    "Create new album from filters" : "سۈزگۈچتىن يېڭى ئالبۇم قۇر",
    "One of the source folders does not exist" : "مەنبە قىسقۇچلارنىڭ بىرى مەۋجۇت ئەمەس",
    "Add to album" : "ئالبۇمغا قوشۇڭ",
    "Delete selection" : "تاللاشنى ئۆچۈرۈڭ",
    "No photos or videos in here" : "بۇ يەردە رەسىم ياكى سىن يوق",
    "Unassigned faces" : "ئىمزاسىز چىراي",
    "Failed to fetch collection." : "يىغىش مەغلۇب بولدى.",
    "Failed to fetch collections list." : "يىغىپ ساقلاش تىزىملىكىنى ئالالمىدى.",
    "Failed to fetch faces list." : "چىراي تىزىملىكىنى ئالالمىدى.",
    "Error fetching files" : "ھۆججەتلەرگە ئېرىشىشتە خاتالىق",
    "All your media" : "بارلىق مېدىيالىرىڭىز",
    "Album {title}" : "توپلام {title}",
    "Shared Albums" : "ھەمبەھىرلەنگەن ئالبۇم",
    "Shared album {title}" : "ھەمبەھىرلەنگەن پىلاستىنكا {title}",
    "Public album {title}" : "ئاممىۋى پىلاستىنكا {title}",
    "Tagged photos" : "خەتكۈچلەنگەن رەسىملەر",
    "Tagged photo {title}" : "خەتكۈچلەنگەن رەسىم {title}",
    "{title}'s face" : "{title} نىڭ يۈزى",
    "Last week" : "ئالدىنقى ھەپتە",
    "Last Month" : "ئالدىنقى ئاي",
    "Custom…" : "خاس...",
    "{startDate} to {endDate}" : "{startDate} دىن {endDate}",
    "Details" : "تەپسىلاتى",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName} نى {collectionFileName} يىغمىسىغا قۇشۇش مەغلۇپ بولدى",
    "Failed to delete {fileBaseName}" : "{fileBaseName} نى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to create {collectionFileName}" : "{collectionFileName} نى قۇرۇش مەغلۇپ بولدى",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "{currentCollectionFileName} نىڭ ئىسمىنى {newCollectionFileName} غا ئۆزگەرتىش مەغلۇپ بولدى",
    "Failed to update properties of {collectionFileName} with {properties}" : "{collectionFileName} نىڭ خاسلىقىنى {properties} بىلەن يېڭىلاش مەغلۇپ بولدى",
    "Delete collection" : "توپلامنى ئۆچۈر",
    "Leave shared album" : "ئورتاقلاشقان ئالبۇمدىن ئايرىل",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "سىز {collectionName} نى ئۆچۈرۈشنى جەزىملەشتۈرەمسىز؟ بۇ ھەركەتنى كەينىگە قايتۇرغىلى بولمايدۇ.",
    "Failed to delete {collectionFileName}" : "{collectionFileName} نى ئۆچۈرۈش مەغلۇپ بولدى",
    "Cancel" : "ۋاز كەچ",
    "Confirm" : "جەزملەشتۈرۈڭ",
    "Failed to move {fileBaseName} to person {faceName}" : "{fileBaseName} نى {faceName} غا يۆتكەش مەغلۇپ بولدى",
    "Failed to remove {fileBaseName}" : "{fileBaseName} نىڭ ئىسمىنى ئۆزگەرتىش مەغلۇپ بولدى",
    "Failed to rename {oldName} to {faceName}" : "{oldName} نىڭ ئىسمىنى {faceName} غا ئۆزگەرتىش مەغلۇپ بولدى",
    "Failed to delete {faceName}" : "{faceName} نى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to delete {fileId}" : "{fileId} نى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to delete {fileName}" : "{fileName} نى ئۆچۈرۈش مەغلۇپ بولدى",
    "Failed to set favorite state for {fileId}" : "{fileId} نىڭ ياقتۇردىغان ھالىتىنى بېكىتىش مەغلۇپ بولدى",
    "Failed to set favorite state for {fileName}" : "{fileName} نىڭ ياقتۇردىغان ھالىتىنى بېكىتىش مەغلۇپ بولدى",
    "Could not load photos folder" : "رەسىم قىسقۇچنى يۈكلىيەلمىدى",
    "Group" : "گۇرۇپپا",
    "Remove {collaboratorLabel} from the collaborators list" : "ھەمكارلاشقۇچىلار تىزىملىكىدىن {collaboratorLabel} نى ئۆچۈرۈڭ",
    "Back to {folder}" : "{folder} قايتىش",
    "Share this folder" : "بۇ قىسقۇچنى ھەمبەھىرلەڭ",
    "Enable squared photos view" : "كۋادرات رەسىم كۆرۈنۈشىنى قوزغىتىڭ",
    "Choose default Photos upload and Albums location" : "سۈكۈتتىكى رەسىم يوللاش ۋە پىلاستىنكا ئورنىنى تاللاڭ",
    "Choose a different folder" : "باشقا ھۆججەت قىسقۇچنى تاللاڭ",
    "View" : "كۆرۈش",
    "Choose the folder where photos and albums are uploaded to." : "رەسىم ۋە پىلاستىنكىلار يۈكلەنگەن ھۆججەت قىسقۇچنى تاللاڭ.",
    "Loading folders …" : "ھۆججەت قىسقۇچلارنى يۈكلەۋاتىدۇ…",
    "Add" : "قوش"
},
"nplurals=2; plural=(n != 1);");
